@@ -1,7 +1,6 @@
 import pytest
 
-from dcicutils.misc_utils import ignored
-from dcicutils.qa_utils import override_environ
+from dcicutils.misc_utils import ignored, override_environ
 from unittest import mock
 from ..submission import DEFAULT_INGESTION_TYPE
 from ..base import KeyManager
@@ -32,7 +31,7 @@ def test_submit_metadata_bundle_script(keyfile):
 
                     mock_submit_any_ingestion.side_effect = mocked_submit_metadata_bundle
                     submit_metadata_bundle_main(args_in)
-                    mock_submit_any_ingestion.assert_called_with(**expect_call_args)
+                    raise AssertionError("submit_metadata_bundle_main should not exit normally.")  # pragma: no cover
                 except SystemExit as e:
                     assert e.code == expect_exit_code
                 assert mock_submit_any_ingestion.call_count == (1 if expect_called else 0)
@@ -47,6 +46,8 @@ def test_submit_metadata_bundle_script(keyfile):
         'project': None,
         'validate_only': False,
         'upload_folder': None,
+        'no_query': False,
+        'subfolders': False,
     })
     expect_call_args = {
         'ingestion_filename': 'some-file',
@@ -57,6 +58,8 @@ def test_submit_metadata_bundle_script(keyfile):
         'project': "some-project",
         'validate_only': True,
         'upload_folder': None,
+        'no_query': False,
+        'subfolders': False,
     }
     test_it(args_in=["--env", "some-env", "--institution", "some-institution",
                      "-s", "some-server", "-v", "-p", "some-project",
@@ -78,6 +81,8 @@ def test_submit_metadata_bundle_script(keyfile):
         'project': "some-project",
         'validate_only': False,
         'upload_folder': 'a-folder',
+        'no_query': False,
+        'subfolders': False,
     }
     test_it(args_in=["--env", "some-env",
                      "--institution", "some-institution",
@@ -106,6 +111,8 @@ def test_submit_metadata_bundle_script(keyfile):
         'project': "some-project",
         'validate_only': True,
         'upload_folder': 'a-folder',
+        'no_query': False,
+        'subfolders': False,
     }
     test_it(args_in=["--env", "some-env",
                      "--institution", "some-institution",
@@ -129,3 +136,27 @@ def test_submit_metadata_bundle_script(keyfile):
             expect_exit_code=0,
             expect_called=True,
             expect_call_args=expect_call_args)
+    expect_call_args = {
+        'ingestion_filename': 'some-file',
+        'ingestion_type': DEFAULT_INGESTION_TYPE,
+        'env': "some-env",
+        'server': "some-server",
+        'institution': "some-institution",
+        'project': "some-project",
+        'validate_only': True,
+        'upload_folder': None,
+        'no_query': True,
+        'subfolders': True,
+    }
+    test_it(args_in=["--env", "some-env", "--institution", "some-institution",
+                     "-s", "some-server", "-v", "-p", "some-project",
+                     'some-file', '-nq', '-sf'],
+            expect_exit_code=0,
+            expect_called=True,
+            expect_call_args=expect_call_args)
+    test_it(args_in=["--env", "some-env", "--institution", "some-institution",
+                     "-s", "some-server", "-v", "-p", "some-project",
+                     'some-file', '--no_query', '--subfolders'],
+            expect_exit_code=0,
+            expect_called=True,
+            expect_call_args=expect_call_args)
